@@ -1,9 +1,9 @@
 # calc.py
-def add(x: int, y: int) -> int:
+def add(x, y):
  return x + y
   
   
-def sub(x: int, y: int) -> int:
+def sub(x, y):
  return x - y
   
 # __init__.py
